==> haskell-monad-loops-0.4.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-loops
version:              0.4.3
visibility:           public
id:                   monad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ
key:                  monad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/monad-loops
synopsis:             Monadic loops
description:
    Some useful control operators for looping.

    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.

    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.

category:             Control
abi:                  e690a7076c5c22130c2efdf33b07cf2f
exposed:              True
exposed-modules:      Control.Monad.Loops
import-dirs:          /usr/lib/ghc-9.0.1/site-local/monad-loops-0.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monad-loops-0.4.3
hs-libraries:         HSmonad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html:         /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-loops-0.4.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-loops
version:              0.4.3
visibility:           public
id:                   monad-loops-0.4.3-C4VZ1LczQKA9hVl8DS9fX
key:                  monad-loops-0.4.3-C4VZ1LczQKA9hVl8DS9fX
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/monad-loops
synopsis:             Monadic loops
description:
    Some useful control operators for looping.

    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.

    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.

category:             Control
abi:                  2124ccd16bb7f039434e1bcb91f8e53d
exposed:              True
exposed-modules:      Control.Monad.Loops
import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-loops-0.4.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/monad-loops-0.4.3
hs-libraries:         HSmonad-loops-0.4.3-C4VZ1LczQKA9hVl8DS9fX
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html:         /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
